<!--
https://pypi.org/project/readme-generator/
https://pypi.org/project/python-readme-generator/
-->

[![](https://img.shields.io/badge/OS-MacOS-blue.svg?longCache=True)]()
[![](https://img.shields.io/pypi/pyversions/mac-desktop.svg?longCache=True)](https://pypi.org/project/mac-desktop/)

#### Installation
```bash
$ [sudo] pip install mac-desktop
```

#### Examples
```python
>>> import mac_desktop
>>> if mac_desktop.visibility()<0.7:    # Desktop hidden?
...     mac_desktop.toggle()            # show Desktop
```

<p align="center">
    <a href="https://pypi.org/project/python-readme-generator/">python-readme-generator</a>
</p>